summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorruki <[email protected]>2023-08-31 00:03:14 +0800
committerruki <[email protected]>2023-08-31 00:03:14 +0800
commit2db1266629941c424b9a758221e8293e09fb7f32 (patch)
tree9bc5065afc81cd39f42c95ec2db4677b114088c2
parent219c5dcbc69dddda3ca9637c9de3b6affc5dcf8b (diff)
improve git shallow clone #4151
-rw-r--r--xmake/modules/private/action/require/impl/actions/download.lua4
1 files changed, 2 insertions, 2 deletions
diff --git a/xmake/modules/private/action/require/impl/actions/download.lua b/xmake/modules/private/action/require/impl/actions/download.lua
index c498dea82..06ebae308 100644
--- a/xmake/modules/private/action/require/impl/actions/download.lua
+++ b/xmake/modules/private/action/require/impl/actions/download.lua
@@ -95,8 +95,8 @@ function _checkout(package, url, sourcedir, opt)
branch = nil
end
- -- only shadow clone this branch
- git.clone(url, {depth = 1, recursive = true, longpaths = longpaths, branch = branch, outputdir = packagedir})
+ -- only shallow clone this branch
+ git.clone(url, {depth = 1, recursive = true, shallow_submodules = true, longpaths = longpaths, branch = branch, outputdir = packagedir})
-- download package from revision or tag?
else